( function( $ ) {

	/**
	 * Responsive video
	 */
	function responsiveVideo() {
		$( '.entry, .widget' ).fitVids();
	}

	/**
	 * Search button
	 */
	function searchButton() {
		var $search = $( '.searchbar' );
		$( '.search-toggle' ).on( 'click', function( event ) {
			event.preventDefault();
			$search.fadeToggle( 300 );
			$( '.searchbar-field' ).focus();
		} );
		$( '.search-close' ).on( 'click', function( event ) {
			event.preventDefault();
			$search.fadeToggle( 300 );
		} );
	}

	/**
	 * Mobile menu
	 */
	function mobileMenu() {
		$( '#menu-primary-items' ).slicknav( {
			label: '',
			prependTo: '.menu-primary-container',
			allowParentLinks: true
		} );
	}

	/**
	 * Featured posts slider
	 */
	function featuredPosts() {
		$( '.featured-posts' ).owlCarousel( {
			items: 1,
			nav: true,
			dots: false,
			navText: [
				'<i class="fa fa-chevron-left" aria-hidden="true"></i>',
				'<i class="fa fa-chevron-right" aria-hidden="true"></i>'
			],
			loop: true,
			autoplay: true
		} );
	}

	/**
	 * Post format gallery
	 */
	function formatGallery() {
		$( '.format-gallery-slider' ).owlCarousel( {
			items: 1,
			nav: true,
			dots: false,
			navText: [
				'<i class="fa fa-long-arrow-left" aria-hidden="true"></i>',
				'<i class="fa fa-long-arrow-right" aria-hidden="true"></i>'
			],
			loop: true,
			autoplay: true
		} );
	}

	/**
	 * Popup gallery
	 */
	function popupGallery() {
		$( '.entry-gallery' ).magnificPopup( {
			type: 'image',
			delegate: 'a',
			gallery: {
				enabled: true
			}
		} );
	}

	/**
	 * Load more posts
	 */
	function loadMorePosts() {

		// Setup a variables.
		var selector = '.load-more-posts',
			action = 'loadmore';

		// Re-setup the variables if on archive and search page.
		if ( highstake_variables.is_archive ) {
			selector = '.load-more-archive-posts';
			action = 'loadmore_archive';
		}

		// Start the ajax pagination.
		$( selector ).on( 'click', function( e ) {

			e.preventDefault();

			var button = $( this ),
				data = {
					'action': action,
					'query': highstake_variables.posts,
					'page': highstake_variables.current_page
				};

			$.ajax( {
				url: highstake_variables.ajax_url, // AJAX handler
				data: data,
				type: 'POST',
				beforeSend: function( xhr ) {
					button.text( highstake_variables.loading );
				},
				success: function( data ) {
					if ( data ) {
						button.text( highstake_variables.btn_text ).before( data ); // Insert new posts
						highstake_variables.current_page++;

						if ( highstake_variables.current_page == highstake_variables.max_page )
							button.remove(); // If last page, remove the button

					} else {
						button.remove(); // If no data, remove the button as well
					}
				}
			} );
		} );

	}

	// Document ready
	$( function() {
		responsiveVideo();
		searchButton();
		mobileMenu();
		featuredPosts();
		formatGallery();
		popupGallery();
		loadMorePosts();
	} );

}( jQuery ) );
