<?php
/**
 * Highstake Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/custom-text.php';

// Loads the customizer settings
require trailingslashit( get_template_directory() ) . 'inc/customizer/general.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/header.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/post.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/page.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/footer.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/featured.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/callout.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/fonts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/colors.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/retina-logo.php';

/**
 * Custom customizer functions.
 */
function highstake_customize_functions( $wp_customize ) {

	// Register new panel: Design
	$wp_customize->add_panel( 'highstake_design', array(
		'title'       => esc_html__( 'Theme Design', 'highstake' ),
		'description' => esc_html__( 'This panel is used for customizing the design of your site.', 'highstake' ),
		'priority'    => 125,
	) );

	// Register new panel: Theme Options
	$wp_customize->add_panel( 'highstake_options', array(
		'title'       => esc_html__( 'Theme Options', 'highstake' ),
		'description' => esc_html__( 'This panel is used for customizing the Highstake theme.', 'highstake' ),
		'priority'    => 130,
	) );

	// Live preview of Site Title
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback'  => function() {
				return get_bloginfo( 'name', 'display' );
			}
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'highstake_design';
	$wp_customize->get_section( 'colors' )->priority = 1;

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'highstake_design';
	$wp_customize->get_section( 'background_image' )->priority = 7;

	// Move the Additional CSS section.
	$wp_customize->get_section( 'custom_css' )->panel    = 'highstake_design';
	$wp_customize->get_section( 'custom_css' )->priority = 9;

	// Move background color to background image section.
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'highstake' );
	$wp_customize->get_control( 'background_color' )->section = 'background_image';


}
add_action( 'customize_register', 'highstake_customize_functions', 99 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function highstake_customize_preview_js() {
	wp_enqueue_script( 'highstake-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'highstake_customize_preview_js' );

/**
 * Display theme documentation on customizer page.
 */
function highstake_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'highstake-doc', get_template_directory_uri() . '/assets/js/customizer/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'highstake-doc', 'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/highstake/' ),
			'prefixLabel' => esc_html__( 'Documentation', 'highstake' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'highstake_documentation_link' );

/**
 * Custom styles.
 */
function highstake_custom_css() {

	// Set up empty variable.
	$css = '';

	// Get the customizer value.
	$color           = get_theme_mod( 'highstake_accent_color', '#54e5b0' );
	$heading_font    = get_theme_mod( 'highstake_heading_font_family', '\'Montserrat\', sans-serif' );
	$body_font       = get_theme_mod( 'highstake_body_font_family', '\'Karla\', sans-serif' );

	if ( $color != '#54e5b0' ) {
		$css .= '
		.button-primary,.social-links,.menu-primary-items .sub-menu,.page-header,.tag-links a:hover,.search-toggle:hover {
			background-color: ' . sanitize_hex_color( $color ) . ';
		}

		.cat-link a,h2.entry-title a:hover,.entry-meta a:hover,.posts-thumbnail-widget .post-title:hover,.copyright a,.menu-footer-items a:hover,.page-header .cat-link a:hover,.page-header .entry-meta a:hover,.author-bio .name a:hover,.logged-in-as a,.entry-content a,.info-right .to-top:hover {
			color: ' . sanitize_hex_color( $color ) . ';
		}

		.menu-primary-items li:hover {
			border-color: ' . sanitize_hex_color( $color ) . ';
		}
		';
	}

	if ( $heading_font != '\'Montserrat\', sans-serif' ) {
		$css .= '
			h1, h2, h3, h4, h5, h6, .entry-author {
				font-family: ' . esc_attr( $heading_font ) . ';
			}
		';
	}

	if ( $body_font != '\'Karla\', sans-serif' ) {
		$css .= '
			body {
				font-family: ' . esc_attr( $body_font ) . ';
			}
		';
	}

	// Print the custom style
	wp_add_inline_style( 'highstake-style', $css );

}
add_action( 'wp_enqueue_scripts', 'highstake_custom_css' );

/**
 * Sanitize the Footer Credits
 */
function highstake_sanitize_textarea( $text ) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$text = $text;
	} else {
		$text = wp_kses_post( $text );
	}
	return $text;
}
